==================================
Review Board 1.7.0.1 Release Notes
==================================

**Release date**: December 17, 2012


Bug Fixes
=========

* Fixed a bug when creating or updating repositories without having an SSH
  key generated.


Contributors
============

* Christian Hammond
